import { dataSource } from "../../../data-source";
import { newsletterConfig } from "../../../entity/settings/newsletterConfig";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import InternalException from "../../../exceptions/internalException";
import { SetNewsletterConfigCommand } from "./newsletterConfigCommand";

export default abstract class NewsletterConfigCommandHandler {
  /**
   * @description set newsletterConfig
   * @param {SetNewsletterConfigCommand} setNewsletterConfig
   * @returns {Promise<number>}
   */
  static async set(setNewsletterConfig: SetNewsletterConfigCommand): Promise<number> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(newsletterConfig)
      .values({
        comTypeId: setNewsletterConfig.comTypeId,
        config: setNewsletterConfig.config,
      })
      .orUpdate(["config"], "comTypeId")
      .execute()
      .then((result) => {
        return result.identifiers[0].id;
      })
      .catch((err) => {
        throw new DatabaseActionException("SET", "newsletterConfig", err);
      });
  }
}
