import express, { Request, Response } from "express";
import {
  createSalutation,
  deleteSalutation,
  getAllSalutations,
  getSalutationById,
  updateSalutation,
} from "../../../controller/admin/settings/salutationController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllSalutations(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getSalutationById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "settings", "salutation"),
  async (req: Request, res: Response) => {
    await createSalutation(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "settings", "salutation"),
  async (req: Request, res: Response) => {
    await updateSalutation(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "settings", "salutation"),
  async (req: Request, res: Response) => {
    await deleteSalutation(req, res);
  }
);

export default router;
